@@ -27,7 +27,7 @@ class Auction(object):
         First call for the auction (Generally implemented by a rich PBN file)
     """
 
-    def __init__(self, calls: Union[List[Call], None]=None, first_caller: str=''):
+    def __init__(self, calls: Union[List[Call], None]=None, first_caller: Union[str, int]=''):
         """Create an auction with the given calls and first_caller."""
         self._first_caller = first_caller
         if not calls:
@@ -63,6 +63,8 @@ class Auction(object):
     def first_caller(self, value):
         """Assign the first_caller value."""
         if value:
+            if isinstance(value, int):
+                value = SEATS[value]
             if not isinstance(value, str):
                 raise TypeError('First caller must be a string')
             if value not in SEATS:
@@ -124,7 +126,10 @@ class Auction(object):
         if not self._first_caller:
             return seat_calls
 
-        seat_index = SEATS.index(self._first_caller)
+        if isinstance(self._first_caller, int):
+            seat_index = self._first_caller
+        else:
+            seat_index = SEATS.index(self._first_caller)
         for call in self.calls:
             seat_calls[SEATS[seat_index]].append(call)
             seat_index += 1
