@@ -8,7 +8,7 @@ from .auction import Auction
 from .contract import Contract
 from .trick import Trick
 
-from .constants import SEATS, RANKS, SUITS, VULNERABLE, SUIT_NAMES, CARD_NAMES
+from .constants import SEATS, RANKS, SUITS, VULNERABLE, SUIT_NAMES, CARD_NAMES, DENOMINATION_NAMES
 
 __all__ = ['Board']
 
@@ -59,6 +59,9 @@ class Board(object):
         self.EW_tricks = 0
         self.play_notes: Dict[str, str] = {}
         self.description = ""
+        self.result = ""
+        self.declarers_tricks = 0
+        self.optimum_result_table = {seat: {denomination: 0 for denomination in DENOMINATION_NAMES} for seat in SEATS}
 
     def _set_hands(self, hands: List[Hand]) -> Tuple[Dict[object, Hand], Dict[int, Hand], Dict[str, Hand]]:
         """Return the hands as a dict."""
