@@ -226,7 +226,7 @@ def parse_pbn(file_lines: List[str]) -> List[Event]:
             elif tag == "Result":
                 if value == '?':
                     value = -1
-                if value.isnumeric():
+                if isinstance(value, int) or value.isnumeric():
                     board.declarers_tricks = int(value)
 
             # # Description
